@@ -37,6 +37,7 @@ import android.view.ViewGroup;
 import android.widget.Filter;
 import android.widget.Filterable;
 
+import org.videolan.medialibrary.Tools;
 import org.videolan.medialibrary.media.DummyItem;
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.vlc.BR;
@@ -44,6 +45,7 @@ import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.databinding.AudioBrowserItemBinding;
 import org.videolan.vlc.databinding.AudioBrowserSeparatorBinding;
+import org.videolan.vlc.gui.BaseQueuedAdapter;
 import org.videolan.vlc.gui.helpers.AsyncImageLoader;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.view.FastScroller;
@@ -52,13 +54,12 @@ import org.videolan.vlc.util.MediaItemDiffCallback;
 import org.videolan.vlc.util.MediaItemFilter;
 import org.videolan.vlc.util.Util;
 
-import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.LinkedList;
 import java.util.List;
 
-public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapter.ViewHolder> implements FastScroller.SeparatedAdapter, Filterable {
+public class AudioBrowserAdapter extends BaseQueuedAdapter<MediaLibraryItem[], AudioBrowserAdapter.ViewHolder> implements FastScroller.SeparatedAdapter, Filterable {
 
     private static final String TAG = "VLC/AudioBrowserAdapter";
 
@@ -72,7 +73,6 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
     private int mSelectionCount = 0;
     private int mType;
     private BitmapDrawable mDefaultCover;
-    private ArrayDeque<MediaLibraryItem[]> mPendingUpdates = new ArrayDeque<>();
 
     public AudioBrowserAdapter(Activity context, int type, IEventsHandler eventsHandler, boolean sections) {
         mContext = context;
@@ -187,7 +187,7 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
 
     @MainThread
     public boolean isEmpty() {
-        return getItemCount() == 0;
+        return Tools.isArrayEmpty(peekLast());
     }
 
     public void clear() {
@@ -252,18 +252,28 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
         return datalist.toArray(new MediaLibraryItem[datalist.size()]);
     }
 
-    public void remove(int position) {
-        final MediaLibraryItem[] dataList = new MediaLibraryItem[getItemCount()-1];
-        Util.removePositionInArray(mPendingUpdates.isEmpty() ? mDataList : mPendingUpdates.peekLast(), position, dataList);
+    public void remove(final MediaLibraryItem item) {
+        final MediaLibraryItem[] referenceList = peekLast();
+        if (Tools.isArrayEmpty(referenceList))
+            return;
+        final MediaLibraryItem[] dataList = new MediaLibraryItem[referenceList.length-1];
+        Util.removeItemInArray(referenceList, item, dataList);
         update(dataList);
     }
 
     public void addItem(final int position, final MediaLibraryItem item) {
-        final MediaLibraryItem[] dataList = new MediaLibraryItem[getItemCount()+1];
-        Util.addItemInArray(mPendingUpdates.isEmpty() ? mDataList : mPendingUpdates.peekLast(), position, item, dataList);
+        final MediaLibraryItem[] referenceList = peekLast();
+        final MediaLibraryItem[] dataList = Tools.isArrayEmpty(referenceList)
+                ? new MediaLibraryItem[]{item} : new MediaLibraryItem[referenceList.length+1];
+        Util.addItemInArray(referenceList, position, item, dataList);
         update(dataList);
     }
 
+    @Override
+    public MediaLibraryItem[] peekLast() {
+        return hasPendingUpdates() ? super.peekLast() : mDataList;
+    }
+
     public void restoreList() {
         if (mOriginalDataSet != null) {
             update(Arrays.copyOf(mOriginalDataSet, mOriginalDataSet.length));
@@ -271,14 +281,7 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
         }
     }
 
-    @MainThread
-    void update(final MediaLibraryItem[] items) {
-        mPendingUpdates.add(items);
-        if (mPendingUpdates.size() == 1)
-            internalUpdate(items);
-    }
-
-    private void internalUpdate(final MediaLibraryItem[] items) {
+    protected void internalUpdate(final MediaLibraryItem[] items) {
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
@@ -287,12 +290,10 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
                 VLCApplication.runOnMainThread(new Runnable() {
                     @Override
                     public void run() {
-                        mPendingUpdates.remove();
                         addAll(newList, false);
                         result.dispatchUpdatesTo(AudioBrowserAdapter.this);
                         mIEventsHandler.onUpdateFinished(AudioBrowserAdapter.this);
-                        if (!mPendingUpdates.isEmpty())
-                            internalUpdate(mPendingUpdates.peek());
+                        processQueue();
                     }
                 });
             }
@@ -362,20 +363,20 @@ public class AudioBrowserAdapter extends RecyclerView.Adapter<AudioBrowserAdapte
 
         public void onClick(View v) {
             if (mIEventsHandler != null) {
-                int position = getAdapterPosition();
+                int position = getLayoutPosition();
                 mIEventsHandler.onClick(v, position, mDataList[position]);
             }
         }
 
         public void onMoreClick(View v) {
             if (mIEventsHandler != null) {
-                int position = getAdapterPosition();
+                int position = getLayoutPosition();
                 mIEventsHandler.onCtxClick(v, position, mDataList[position]);
             }
         }
 
         public boolean onLongClick(View view) {
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             return mIEventsHandler.onLongClick(view, position, mDataList[position]);
         }
 
