@@ -43,11 +43,11 @@ import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.databinding.BrowserItemBinding;
 import org.videolan.vlc.databinding.BrowserItemSeparatorBinding;
+import org.videolan.vlc.gui.BaseQueuedAdapter;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.util.MediaItemDiffCallback;
 import org.videolan.vlc.util.MediaItemFilter;
 
-import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -55,7 +55,7 @@ import static org.videolan.medialibrary.media.MediaLibraryItem.FLAG_SELECTED;
 import static org.videolan.medialibrary.media.MediaLibraryItem.TYPE_MEDIA;
 import static org.videolan.medialibrary.media.MediaLibraryItem.TYPE_STORAGE;
 
-public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.ViewHolder> implements Filterable {
+public class BaseBrowserAdapter extends BaseQueuedAdapter<ArrayList<MediaLibraryItem>, BaseBrowserAdapter.ViewHolder> implements Filterable {
     protected static final String TAG = "VLC/BaseBrowserAdapter";
 
     private static int FOLDER_RES_ID = R.drawable.ic_menu_folder;
@@ -161,14 +161,14 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
         }
 
         protected void openStorage() {
-            MediaWrapper mw = new MediaWrapper(((Storage) getItem(getAdapterPosition())).getUri());
+            MediaWrapper mw = new MediaWrapper(((Storage) getItem(getLayoutPosition())).getUri());
             mw.setType(MediaWrapper.TYPE_DIR);
-            fragment.browse(mw, getAdapterPosition(), binding.browserCheckbox.isChecked());
+            fragment.browse(mw, getLayoutPosition(), binding.browserCheckbox.isChecked());
         }
 
         public void onCheckBoxClick(View v) {
-            if (getItem(getAdapterPosition()).getItemType() == TYPE_STORAGE)
-                checkBoxAction(v, ((Storage) getItem(getAdapterPosition())).getUri().getPath());
+            if (getItem(getLayoutPosition()).getItemType() == TYPE_STORAGE)
+                checkBoxAction(v, ((Storage) getItem(getLayoutPosition())).getUri().getPath());
         }
 
         @Override
@@ -177,18 +177,18 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
         }
 
         public void onClick(View v){
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             fragment.onClick(v, position, mMediaList.get(position));
         }
 
         public void onMoreClick(View v) {
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             fragment.onCtxClick(v, position, mMediaList.get(position));
         }
 
         @Override
         public boolean onLongClick(View v) {
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             return fragment.onLongClick(v, position, mMediaList.get(position));
         }
 
@@ -219,7 +219,12 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
     }
 
     public boolean isEmpty(){
-        return mMediaList.isEmpty();
+        return peekLast().isEmpty();
+    }
+
+    @Override
+    public ArrayList<MediaLibraryItem> peekLast() {
+        return hasPendingUpdates() ? super.peekLast() : mMediaList;
     }
 
     public void addItem(MediaLibraryItem item, boolean top){
@@ -232,7 +237,7 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
 
     void addItem(MediaLibraryItem item, boolean top, int positionTo){
         int position;
-        ArrayList<MediaLibraryItem> list = new ArrayList<>(mPendingUpdates.isEmpty() ? mMediaList : mPendingUpdates.peekLast());
+        ArrayList<MediaLibraryItem> list = new ArrayList<>(peekLast());
         if (positionTo != -1)
             position = positionTo;
         else
@@ -244,8 +249,10 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
         if (item .getItemType() == TYPE_MEDIA && (((MediaWrapper) item).getType() == MediaWrapper.TYPE_VIDEO || ((MediaWrapper) item).getType() == MediaWrapper.TYPE_AUDIO))
             mMediaCount++;
 
-        list.add(position, item);
-        update(list);
+        if (position <= list.size()) {
+            list.add(position, item);
+            update(list);
+        }
     }
 
     public void setTop (int top) {
@@ -259,26 +266,28 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
     void removeItem(int position) {
         if (position >= getItemCount())
             return;
-        MediaLibraryItem item = mMediaList.get(position);
-        ArrayList<MediaLibraryItem> list = new ArrayList<>(mPendingUpdates.isEmpty() ? mMediaList : mPendingUpdates.peekLast());
-        list.remove(position);
-        update(list);
-        if (item .getItemType() == TYPE_MEDIA && (((MediaWrapper) item).getType() == MediaWrapper.TYPE_VIDEO || ((MediaWrapper) item).getType() == MediaWrapper.TYPE_AUDIO))
+        removeItem(mMediaList.get(position));
+    }
+
+    void removeItem(MediaLibraryItem item) {
+        if (item.getItemType() == TYPE_MEDIA && (((MediaWrapper) item).getType() == MediaWrapper.TYPE_VIDEO || ((MediaWrapper) item).getType() == MediaWrapper.TYPE_AUDIO))
             mMediaCount--;
+        ArrayList<MediaLibraryItem> list = new ArrayList<>(peekLast());
+        list.remove(item);
+        update(list);
     }
 
     void removeItem(String path) {
-        int position = -1;
-        for (int i = 0; i< getItemCount(); ++i) {
-            MediaLibraryItem item = mMediaList.get(i);
+
+        MediaLibraryItem mediaItem = null;
+        for (MediaLibraryItem item : mMediaList) {
             if (item .getItemType() == TYPE_MEDIA && TextUtils.equals(path, ((MediaWrapper) item).getUri().toString())) {
-                position = i;
+                mediaItem = item;
                 break;
             }
         }
-        if (position == -1)
-            return;
-        removeItem(position);
+        if (mediaItem != null)
+            removeItem(mediaItem);
     }
 
     public ArrayList<MediaLibraryItem> getAll(){
@@ -352,34 +361,23 @@ public class BaseBrowserAdapter extends RecyclerView.Adapter<BaseBrowserAdapter.
         return mFilter;
     }
 
-    private ArrayDeque<ArrayList<MediaLibraryItem>> mPendingUpdates = new ArrayDeque<>();
-
-    @MainThread
-    void update(final ArrayList<MediaLibraryItem> items) {
-        mPendingUpdates.add(items);
-        if (mPendingUpdates.size() == 1)
-            internalUpdate(items);
-    }
-
-    private void internalUpdate(final ArrayList<MediaLibraryItem> items) {
+    protected void internalUpdate(final ArrayList<MediaLibraryItem> items) {
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
                 final DiffUtil.DiffResult result = DiffUtil.calculateDiff(new MediaItemDiffCallback(mMediaList, items), false);
                 for (MediaLibraryItem item : items) {
                     if (item.getItemType() == MediaLibraryItem.TYPE_MEDIA
-                            && (((MediaWrapper)item).getType() == MediaWrapper.TYPE_AUDIO|| (AndroidUtil.isHoneycombOrLater() && ((MediaWrapper)item).getType() == MediaWrapper.TYPE_VIDEO)))
+                            && (((MediaWrapper)item).getType() == MediaWrapper.TYPE_AUDIO|| (AndroidUtil.isHoneycombOrLater && ((MediaWrapper)item).getType() == MediaWrapper.TYPE_VIDEO)))
                         mMediaCount++;
                 }
                 VLCApplication.runOnMainThread(new Runnable() {
                     @Override
                     public void run() {
-                        mPendingUpdates.remove();
                         mMediaList = items;
                         result.dispatchUpdatesTo(BaseBrowserAdapter.this);
                         fragment.onUpdateFinished(null);
-                        if (!mPendingUpdates.isEmpty())
-                            internalUpdate(mPendingUpdates.peek());
+                        processQueue();
                     }
                 });
             }
