@@ -96,6 +96,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
     public static final long HEADER_NETWORK = 3;
     public static final long HEADER_DIRECTORIES = 4;
     public static final long HEADER_MISC = 5;
+    public static final long HEADER_STREAM = 6;
 
     public static final long ID_SETTINGS = 0;
     public static final long ID_ABOUT = 1;
@@ -234,7 +235,10 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
                 // If request is cancelled, the result arrays are empty.
                 if (grantResults.length > 0
                         && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
-                    startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
+                    Intent serviceIntent = new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class);
+                    serviceIntent.putExtra(StartActivity.EXTRA_FIRST_RUN, getIntent().getBooleanExtra(StartActivity.EXTRA_FIRST_RUN, false));
+                    serviceIntent.putExtra(StartActivity.EXTRA_UPGRADE, getIntent().getBooleanExtra(StartActivity.EXTRA_UPGRADE, false));
+                    startService(serviceIntent);
                 } else {
                     Permissions.showStoragePermissionDialog(this, false);
                 }
@@ -495,6 +499,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
             mOtherAdapter.add(new CardPresenter.SimpleCard(ID_ABOUT, getString(R.string.about), getString(R.string.app_name_full)+" "+ BuildConfig.VERSION_NAME, R.drawable.ic_tv_icon_small));
             mOtherAdapter.add(new CardPresenter.SimpleCard(ID_LICENCE, getString(R.string.licence), R.drawable.ic_tv_icon_small));
             mRowsAdapter.add(new ListRow(miscHeader, mOtherAdapter));
+            mBrowseFragment.setSelectedPosition(Math.min(mBrowseFragment.getSelectedPosition(), mRowsAdapter.size()-1));
             mBrowseFragment.setAdapter(mRowsAdapter);
         }
     }
@@ -526,6 +531,7 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         if (AndroidDevices.hasLANConnection()) {
             final ArrayList<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
             mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_NETWORK, getString(R.string.network_browsing), R.drawable.ic_menu_network_big));
+            mBrowserAdapter.add(new CardPresenter.SimpleCard(HEADER_STREAM, getString(R.string.open_mrl), R.drawable.ic_menu_stream_big));
 
             if (!favs.isEmpty()) {
                 for (MediaWrapper fav : favs) {
