@@ -82,7 +82,7 @@ import org.videolan.vlc.util.VLCInstance;
 import java.util.ArrayList;
 import java.util.List;
 
-public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, DevicesDiscoveryCb, MediaAddedCb, Filterable, IEventsHandler {
+public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, DevicesDiscoveryCb, MediaAddedCb, Filterable, IEventsHandler, View.OnClickListener {
 
     public final static String TAG = "VLC/VideoListFragment";
 
@@ -124,6 +124,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         mSearchButtonView = v.findViewById(R.id.searchButton);
 
         mSwipeRefreshLayout.setOnRefreshListener(this);
+        mTextViewNomedia.setOnClickListener(this);
 
         mDividerItemDecoration = new DividerItemDecoration(v.getContext(), DividerItemDecoration.VERTICAL);
         if (mVideoAdapter.isListMode())
@@ -276,7 +277,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
                 showInfoDialog(media);
                 return true;
             case R.id.video_list_delete:
-                removeVideo(position, media);
+                removeVideo(media);
                 return true;
             case R.id.video_group_play:
                 MediaUtils.openList(getActivity(), ((MediaGroup) media).getAll(), 0);
@@ -294,8 +295,8 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         return false;
     }
 
-    private void removeVideo(int position, final MediaWrapper media) {
-        mVideoAdapter.remove(position);
+    private void removeVideo(final MediaWrapper media) {
+        mVideoAdapter.remove(media);
         if (getView() != null)
             UiTools.snackerWithCancel(getView(), getString(R.string.file_deleted), new Runnable() {
                 @Override
@@ -322,7 +323,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         MenuInflater inflater = getActivity().getMenuInflater();
         inflater.inflate(media instanceof MediaGroup ? R.menu.video_group_contextual : R.menu.video_list, menu);
         if (media instanceof MediaGroup) {
-            if (!AndroidUtil.isHoneycombOrLater()) {
+            if (!AndroidUtil.isHoneycombOrLater) {
                 menu.findItem(R.id.video_list_append).setVisible(false);
                 menu.findItem(R.id.video_group_play).setVisible(false);
             }
@@ -344,7 +345,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         media.release();
         menu.findItem(R.id.video_list_info).setVisible(hasInfo);
         menu.findItem(R.id.video_list_delete).setVisible(canWrite);
-        if (!AndroidUtil.isHoneycombOrLater()) {
+        if (!AndroidUtil.isHoneycombOrLater) {
             menu.findItem(R.id.video_list_play_all).setVisible(false);
             menu.findItem(R.id.video_list_append).setVisible(false);
         }
@@ -521,10 +522,9 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
             stopActionMode();
             return false;
         }
-        boolean honeyComb = AndroidUtil.isHoneycombOrLater();
         menu.findItem(R.id.action_video_info).setVisible(count == 1);
-        menu.findItem(R.id.action_video_play).setVisible(honeyComb || count == 1);
-        menu.findItem(R.id.action_video_append).setVisible(mService.hasMedia() && honeyComb);
+        menu.findItem(R.id.action_video_play).setVisible(AndroidUtil.isHoneycombOrLater || count == 1);
+        menu.findItem(R.id.action_video_append).setVisible(mService.hasMedia() && AndroidUtil.isHoneycombOrLater);
         return true;
     }
 
@@ -647,7 +647,18 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
 
     @Override
     public void onUpdateFinished(RecyclerView.Adapter adapter) {
+        if (!mMediaLibrary.isWorking())
+            mHandler.sendEmptyMessage(UNSET_REFRESHING);
         updateEmptyView();
         setFabPlayVisibility(true);
     }
+
+    @Override
+    public void onClick(View v) {
+        if (v.getId() == R.id.textview_nomedia) {
+            Intent intent = new Intent(v.getContext(), SecondaryActivity.class);
+            intent.putExtra("fragment", SecondaryActivity.STORAGE_BROWSER);
+            startActivity(intent);
+        }
+    }
 }
