@@ -148,9 +148,8 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         holder.binding.setVariable(BR.cover, AsyncImageLoader.DEFAULT_COVER_VIDEO_DRAWABLE);
     }
 
-    public boolean isEmpty()
-    {
-        return mVideos.size() == 0;
+    public boolean isEmpty() {
+        return peekLast().size() == 0;
     }
 
     @Nullable
@@ -164,18 +163,16 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
 
     @MainThread
     public void add(MediaWrapper item) {
-        ArrayList<MediaWrapper> list = new ArrayList<>(mPendingUpdates.isEmpty() ? mVideos : mPendingUpdates.peekLast());
+        ArrayList<MediaWrapper> list = new ArrayList<>(peekLast());
         list.add(item);
         update(list, false);
     }
 
     @MainThread
-    public void remove(int position) {
-        if (position == -1)
-            return;
-        ArrayList<MediaWrapper> list = new ArrayList<>(mPendingUpdates.isEmpty() ? mVideos : mPendingUpdates.peekLast());
-        list.remove(position);
-        update(list, false);
+    public void remove(MediaWrapper item) {
+        ArrayList<MediaWrapper> refList = new ArrayList<>(peekLast());
+        if (refList.remove(item))
+            update(refList, false);
     }
 
     @MainThread
@@ -184,6 +181,11 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         mOriginalData = null;
     }
 
+    @MainThread
+    private ArrayList<MediaWrapper> peekLast() {
+        return mPendingUpdates.isEmpty() ? mVideos : mPendingUpdates.peekLast();
+    }
+
     public boolean contains(MediaWrapper mw) {
         return mVideos.indexOf(mw) != -1;
     }
@@ -327,16 +329,16 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
         }
 
         public void onClick(View v) {
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             mEventsHandler.onClick(v, position, mVideos.get(position));
         }
 
         public void onMoreClick(View v){
-            mEventsHandler.onCtxClick(v, getAdapterPosition(), null);
+            mEventsHandler.onCtxClick(v, getLayoutPosition(), null);
         }
 
         public boolean onLongClick(View v) {
-            int position = getAdapterPosition();
+            int position = getLayoutPosition();
             return mEventsHandler.onLongClick(v, position, mVideos.get(position));
         }
 
@@ -346,7 +348,7 @@ public class VideoListAdapter extends RecyclerView.Adapter<VideoListAdapter.View
 
         @Override
         public void onFocusChange(View v, boolean hasFocus) {
-            setViewBackground(hasFocus || mVideos.get(getAdapterPosition()).hasStateFlags(MediaLibraryItem.FLAG_SELECTED));
+            setViewBackground(hasFocus || mVideos.get(getLayoutPosition()).hasStateFlags(MediaLibraryItem.FLAG_SELECTED));
         }
 
         private void setViewBackground(boolean highlight) {
