@@ -12,15 +12,18 @@ import android.support.v4.content.LocalBroadcastManager;
 import android.text.TextUtils;
 
 import org.videolan.libvlc.util.AndroidUtil;
+import org.videolan.medialibrary.Tools;
+import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.SubtitlesDownloader;
+import org.videolan.vlc.util.Util;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 
 public class MediaUtils {
@@ -35,11 +38,11 @@ public class MediaUtils {
         LocalBroadcastManager.getInstance(VLCApplication.getAppContext()).sendBroadcast(intent);
     }
 
-    public static void getSubs(Activity activity, ArrayList<MediaWrapper> mediaList) {
+    public static void getSubs(Activity activity, List<MediaWrapper> mediaList) {
         getSubs(activity, mediaList, null);
     }
 
-    public static void getSubs(Activity activity, ArrayList<MediaWrapper> mediaList, SubtitlesDownloader.Callback cb) {
+    public static void getSubs(Activity activity, List<MediaWrapper> mediaList, SubtitlesDownloader.Callback cb) {
         if (sSubtitlesDownloader == null)
             sSubtitlesDownloader = new SubtitlesDownloader();
         sSubtitlesDownloader.setActivity(activity);
@@ -69,6 +72,17 @@ public class MediaUtils {
         LocalBroadcastManager.getInstance(VLCApplication.getAppContext()).sendBroadcast(intent);
     }
 
+    public static void appendMedia(final Context context, final List<MediaWrapper> media){
+        if (media == null)
+            return;
+        new DialogCallback(context, new DialogCallback.Runnable() {
+                @Override
+                public void run(PlaybackService service) {
+                    service.append(media);
+                }
+        });
+    }
+
     public static void appendMedia(final Context context, final MediaWrapper media){
         if (media == null)
             return;
@@ -99,20 +113,21 @@ public class MediaUtils {
     public static void openMediaNoUi(final Context context, final MediaWrapper media){
         if (media == null)
             return;
-        if (media.getType() == MediaWrapper.TYPE_VIDEO)
-            VideoPlayerActivity.start(context, media.getUri(), media.getTitle());
-        else
-            new BaseCallBack(context) {
-                @Override
-                public void onConnected(PlaybackService service) {
-                    service.load(media);
-                    mClient.disconnect();
-                }
-            };
+        new BaseCallBack(context) {
+            @Override
+            public void onConnected(PlaybackService service) {
+                service.load(media);
+                mClient.disconnect();
+            }
+        };
+    }
+
+    public static void openArray(final Context context, final MediaWrapper[] array, final int position){
+        openList(context, Arrays.asList(array), position);
     }
 
     public static void openList(final Context context, final List<MediaWrapper> list, final int position){
-        if (list == null || list.isEmpty())
+        if (Util.isListEmpty(list))
             return;
         new DialogCallback(context, new DialogCallback.Runnable() {
             @Override
@@ -176,9 +191,9 @@ public class MediaUtils {
                 : media.getArtist();
         if (media.getLength() > 0L) {
             if (TextUtils.isEmpty(subtitle))
-                subtitle = Strings.millisToString(media.getLength());
+                subtitle = Tools.millisToString(media.getLength());
             else
-                subtitle = subtitle + "  -  " +  Strings.millisToString(media.getLength());
+                subtitle = subtitle + "  -  " +  Tools.millisToString(media.getLength());
         }
         return subtitle;
     }
